pub trait InProgressProofs: Debug {
type SpendProof: Clone + Debug;
type OutputProof: Clone + Debug;
}Expand description
Marker trait representing bundle proofs in the process of being created.
Required Associated Types
Sourcetype SpendProof: Clone + Debug
type SpendProof: Clone + Debug
The proof type of a Sapling spend in the process of being proven.
Sourcetype OutputProof: Clone + Debug
type OutputProof: Clone + Debug
The proof type of a Sapling output in the process of being proven.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
Sourceimpl InProgressProofs for Proven
impl InProgressProofs for Proven
type SpendProof = [u8; 192]
type OutputProof = [u8; 192]
Sourceimpl InProgressProofs for Unproven
Available on crate feature circuit only.
impl InProgressProofs for Unproven
Available on crate feature
circuit only.