ProverProgress

Trait ProverProgress 

pub trait ProverProgress {
    // Required method
    fn update(&mut self, cur: u32, end: u32);
}
Reports on the progress made towards creating proofs for a bundle.

Required Methods

fn update(&mut self, cur: u32, end: u32)

Updates the progress instance with the number of steps completed and the total number of steps.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ProverProgress for ()

Source

fn update(&mut self, _: u32, _: u32)

Source

impl<U: From<(u32, u32)>> ProverProgress for Sender<U>

Available on crate feature std only.
Source

fn update(&mut self, cur: u32, end: u32)

Source

impl<U: ProverProgress> ProverProgress for &mut U

Source

fn update(&mut self, cur: u32, end: u32)

Implementors