Struct sapling_crypto::bundle::SpendDescription
source · pub struct SpendDescription<A: Authorization> { /* private fields */ }Implementations
sourceimpl<A: Authorization> SpendDescription<A>
impl<A: Authorization> SpendDescription<A>
sourcepub fn from_parts(
cv: ValueCommitment,
anchor: Scalar,
nullifier: Nullifier,
rk: VerificationKey<SpendAuth>,
zkproof: A::SpendProof,
spend_auth_sig: A::AuthSig
) -> Self
pub fn from_parts( cv: ValueCommitment, anchor: Scalar, nullifier: Nullifier, rk: VerificationKey<SpendAuth>, zkproof: A::SpendProof, spend_auth_sig: A::AuthSig ) -> Self
Constructs a v4 SpendDescription from its constituent parts.
sourcepub fn cv(&self) -> &ValueCommitment
pub fn cv(&self) -> &ValueCommitment
Returns the commitment to the value consumed by this spend.
sourcepub fn anchor(&self) -> &Scalar
pub fn anchor(&self) -> &Scalar
Returns the root of the Sapling commitment tree that this spend commits to.
sourcepub fn rk(&self) -> &VerificationKey<SpendAuth>
pub fn rk(&self) -> &VerificationKey<SpendAuth>
Returns the randomized verification key for the note being spent.
sourcepub fn zkproof(&self) -> &A::SpendProof
pub fn zkproof(&self) -> &A::SpendProof
Returns the proof for this spend.
sourcepub fn spend_auth_sig(&self) -> &A::AuthSig
pub fn spend_auth_sig(&self) -> &A::AuthSig
Returns the authorization signature for this spend.