Struct sapling_crypto::circuit::Output
source · pub struct Output {
pub value_commitment_opening: Option<ValueCommitmentOpening>,
pub payment_address: Option<PaymentAddress>,
pub commitment_randomness: Option<Fr>,
pub esk: Option<Fr>,
}Expand description
This is an output circuit instance.
Fields
value_commitment_opening: Option<ValueCommitmentOpening>The opening of a Pedersen commitment to the value being spent.
payment_address: Option<PaymentAddress>The payment address of the recipient
commitment_randomness: Option<Fr>The randomness used to hide the note commitment data
esk: Option<Fr>The ephemeral secret key for DH with recipient