Module keys

Module keys 

Sapling key components.

Implements section 4.2.2 of the Zcash Protocol Specification.

Modules

testingtest-dependencies

Structs

DiversifiedTransmissionKey
The diversified transmission key for a given payment address.
Diversifier
EphemeralPublicKey
An ephemeral public key used to encrypt an output note on-chain.
EphemeralSecretKey
An ephemeral secret key used to encrypt an output note on-chain.
ExpandedSpendingKey
A Sapling expanded spending key
FullViewingKey
A Sapling key that provides the capability to view incoming and outgoing transactions.
NullifierDerivingKey
A key used to derive the nullifier for a Sapling note.
OutgoingViewingKey
An outgoing viewing key
PreparedEphemeralPublicKey
A Sapling ephemeral public key that has been precomputed for trial decryption.
PreparedIncomingViewingKey
A Sapling incoming viewing key that has been precomputed for trial decryption.
ProofGenerationKey
SaplingIvk
SharedSecret
$\mathsf{KA}^\mathsf{Sapling}.\mathsf{SharedSecret} := \mathbb{J}^{(r)}$
SpendAuthorizingKey
A spend authorizing key, used to create spend authorization signatures.
SpendValidatingKey
A key used to validate spend authorization signatures.
ViewingKey

Enums

DecodingError
Errors that can occur in the decoding of Sapling spending keys.