Module pczt

Module pczt 

PCZT support for Sapling.

Structs

Bundle
PCZT fields that are specific to producing the transaction’s Sapling bundle (if any).
Output
Information about a Sapling output within a transaction.
OutputUpdater
An updater for a Sapling PCZT output.
Spend
Information about a Sapling spend within a transaction.
SpendUpdater
An updater for a Sapling PCZT spend.
Unbound
Authorizing data for a bundle of actions that is just missing a binding signature.
Updater
An updater for a Sapling PCZT bundle.
Zip32Derivation
The ZIP 32 derivation path at which a key can be found.

Enums

IoFinalizerError
Errors that can occur while finalizing the I/O for a PCZT bundle.
ParseError
Errors that can occur while parsing a PCZT bundle.
ProverErrorcircuit
Errors that can occur while creating Sapling proofs for a PCZT.
SignerError
Errors that can occur while signing an Orchard action in a PCZT.
TxExtractorError
Errors that can occur while extracting a regular Sapling bundle from a PCZT bundle.
UpdaterError
Errors that can occur while updating a Sapling bundle in a PCZT.
VerifyError
Errors that can occur while verifying a PCZT bundle.