pub enum ProverError {
InvalidDiversifier,
MissingProofGenerationKey,
MissingRandomSeed,
MissingRecipient,
MissingSpendAuthRandomizer,
MissingValue,
MissingValueCommitTrapdoor,
MissingWitness,
}Expand description
Errors that can occur while creating Sapling proofs for a PCZT.
Variants
InvalidDiversifier
MissingProofGenerationKey
The Prover role requires all proof_generation_key fields to be set.
MissingRandomSeed
The Prover role requires all rseed fields to be set.
MissingRecipient
The Prover role requires all recipient fields to be set.
MissingSpendAuthRandomizer
The Prover role requires all alpha fields to be set.
MissingValue
The Prover role requires all value fields to be set.
MissingValueCommitTrapdoor
The Prover role requires all rcv fields to be set.
MissingWitness
The Prover role requires all witness fields to be set.