pub enum VerifyError {
Show 13 variants
InvalidExtractedNoteCommitment,
InvalidNullifier,
InvalidRandomizedVerificationKey,
InvalidValueCommitment,
MismatchedFullViewingKey,
MissingProofGenerationKey,
MissingRandomSeed,
MissingRecipient,
MissingSpendAuthRandomizer,
MissingValue,
MissingValueCommitTrapdoor,
MissingWitness,
WrongFvkForNote,
}Expand description
Errors that can occur while verifying a PCZT bundle.
Variants
InvalidExtractedNoteCommitment
The output note’s components do not produce the expected cmx.
InvalidNullifier
The spent note’s components do not produce the expected nullifier.
InvalidRandomizedVerificationKey
The Spend’s FVK and alpha do not produce the expected rk.
InvalidValueCommitment
The action’s cv_net does not match the provided note values and rcv.
MismatchedFullViewingKey
The spend or output’s fvk field does not match the provided FVK.
MissingProofGenerationKey
Dummy notes must have their proof_generation_key field set in order to be verified.
MissingRandomSeed
nullifier verification requires rseed to be set.
MissingRecipient
nullifier verification requires recipient to be set.
MissingSpendAuthRandomizer
rk verification requires alpha to be set.
MissingValue
Verification requires all value fields to be set.
MissingValueCommitTrapdoor
cv_net verification requires rcv to be set.
MissingWitness
nullifier verification requires witness to be set.
WrongFvkForNote
The provided fvk does not own the spent note.