sapling_crypto::value

Module testing

source
Available on crate feature test-dependencies only.
Generators for property testing.

Functions

  • Generate an arbitrary value in the range of valid nonnegative amounts.
  • Generate an arbitrary value in the range of valid positive amounts less than a specified value.
  • Generate an arbitrary value in the range of valid positive amounts less than a specified value.
  • Generate an arbitrary ValueCommitTrapdoor