Trait sapling_crypto::builder::InProgressProofs
source · pub trait InProgressProofs: Debug {
type SpendProof: Clone + Debug;
type OutputProof: Clone + Debug;
}Expand description
Marker trait representing bundle proofs in the process of being created.
Required Associated Types
sourcetype SpendProof: Clone + Debug
type SpendProof: Clone + Debug
The proof type of a Sapling spend in the process of being proven.
sourcetype OutputProof: Clone + Debug
type OutputProof: Clone + Debug
The proof type of a Sapling output in the process of being proven.