pub trait ProverProgress {
    // Required method
    fn update(&mut self, cur: u32, end: u32);
}
Reports on the progress made towards creating proofs for a bundle.

Required Methods

source

fn update(&mut self, cur: u32, end: u32)

Updates the progress instance with the number of steps completed and the total number of steps.

Implementations on Foreign Types

source

impl ProverProgress for ()

source

fn update(&mut self, _: u32, _: u32)

source

impl<U: From<(u32, u32)>> ProverProgress for Sender<U>

source

fn update(&mut self, cur: u32, end: u32)

source

impl<U: ProverProgress> ProverProgress for &mut U

source

fn update(&mut self, cur: u32, end: u32)

Implementors