Sapling key components.
Implements section 4.2.2 of the Zcash Protocol Specification.
Modules
- testing
test-dependencies
Structs
- Diversified
Transmission Key - The diversified transmission key for a given payment address.
- Diversifier
- Ephemeral
Public Key - An ephemeral public key used to encrypt an output note on-chain.
- Ephemeral
Secret Key - An ephemeral secret key used to encrypt an output note on-chain.
- Expanded
Spending Key - A Sapling expanded spending key
- Full
Viewing Key - A Sapling key that provides the capability to view incoming and outgoing transactions.
- Nullifier
Deriving Key - A key used to derive the nullifier for a Sapling note.
- Outgoing
Viewing Key - An outgoing viewing key
- Prepared
Ephemeral Public Key - A Sapling ephemeral public key that has been precomputed for trial decryption.
- Prepared
Incoming Viewing Key - A Sapling incoming viewing key that has been precomputed for trial decryption.
- Proof
Generation Key - Sapling
Ivk - Shared
Secret - $\mathsf{KA}^\mathsf{Sapling}.\mathsf{SharedSecret} := \mathbb{J}^{(r)}$
- Spend
Authorizing Key - A spend authorizing key, used to create spend authorization signatures.
- Spend
Validating Key - A key used to validate spend authorization signatures.
- Viewing
Key
Enums
- Decoding
Error - Errors that can occur in the decoding of Sapling spending keys.